@@ -12,9 +12,9 @@
 #include <grantlee/parser.h>
 #include <grantlee/variable.h>
 #else
-#include <KTextTemplate/exception.h>
-#include <KTextTemplate/parser.h>
-#include <KTextTemplate/variable.h>
+#include <KTextTemplate/Exception>
+#include <KTextTemplate/Parser>
+#include <KTextTemplate/Variable>
 #endif
 
 #include <KIconLoader>
@@ -39,11 +39,9 @@ KTextTemplate::Node *IconTag::getNode(const QString &tagContent, KTextTemplate::
 {
     Q_UNUSED(p)
 
-    static QHash<QString, int> sizeOrGroupLookup = {{QStringLiteral("desktop"), KIconLoader::Desktop},
-                                                    {QStringLiteral("toolbar"), KIconLoader::Toolbar},
+    static QHash<QString, int> sizeOrGroupLookup = {{QStringLiteral("toolbar"), KIconLoader::Toolbar},
                                                     {QStringLiteral("maintoolbar"), KIconLoader::MainToolbar},
                                                     {QStringLiteral("small"), KIconLoader::Small},
-                                                    {QStringLiteral("panel"), KIconLoader::Panel},
                                                     {QStringLiteral("dialog"), KIconLoader::Dialog},
                                                     {QStringLiteral("sizesmall"), KIconLoader::SizeSmall},
                                                     {QStringLiteral("sizesmallmedium"), KIconLoader::SizeSmallMedium},
