@@ -10,7 +10,7 @@
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/qtlocalizer.h>
 #else
-#include <KTextTemplate/qtlocalizer.h>
+#include <KTextTemplate/QtLocalizer>
 #endif
 
 #include <QLocale>
