@@ -28,7 +28,7 @@ bool ICalDrag::populateMimeData(QMimeData *me, const Calendar::Ptr &cal)
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QString scal = icf.toString(cal, QString(), false);
 #else
-    QString scal = icf.toString(cal, QString());
+    QString scal = icf.toString(cal);
 #endif
 
     if (me && !scal.isEmpty()) {
