@@ -10,7 +10,7 @@
 
 #include "kcalutils_export.h"
 
-#include <KCalendarCore/MemoryCalendar>
+#include <KCalendarCore/Calendar>
 
 class QMimeData;
 
@@ -29,7 +29,7 @@ Q_REQUIRED_RESULT KCALUTILS_EXPORT QString mimeType();
 /**
   Sets the iCalendar representation as data of the drag object
 */
-Q_REQUIRED_RESULT KCALUTILS_EXPORT bool populateMimeData(QMimeData *e, const KCalendarCore::MemoryCalendar::Ptr &cal);
+Q_REQUIRED_RESULT KCALUTILS_EXPORT bool populateMimeData(QMimeData *e, const KCalendarCore::Calendar::Ptr &cal);
 
 /**
   Return, if drag&drop object can be decode to iCalendar.
@@ -39,7 +39,6 @@ Q_REQUIRED_RESULT KCALUTILS_EXPORT bool canDecode(const QMimeData *);
 /**
   Decode drag&drop object to iCalendar component \a cal.
 */
-Q_REQUIRED_RESULT KCALUTILS_EXPORT bool fromMimeData(const QMimeData *e, const KCalendarCore::MemoryCalendar::Ptr &cal);
+Q_REQUIRED_RESULT KCALUTILS_EXPORT bool fromMimeData(const QMimeData *e, const KCalendarCore::Calendar::Ptr &cal);
 }
 }
-
